# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr

class AuthClaim(BaseModel):
    """
    AuthClaim
    """
    name: StrictStr = Field(..., description="The attribute name for the claim when its returned in an Access Token")
    user_attribute_mappings: Optional[StrictStr] = Field(None, description="A user attribute to map values from For custom attributes prefix the name of the attribute with `custom_attribute_`. e.g. To get the value for custom attribute `employee_id` use `custom_attribute_employee_id`.")
    user_attribute_macros: Optional[StrictStr] = Field(None, description="When `user_attribute_mappings` is set to `_macro_` this macro will be used to assign the parameter value.")
    __properties = ["name", "user_attribute_mappings", "user_attribute_macros"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AuthClaim:
        """Create an instance of AuthClaim from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AuthClaim:
        """Create an instance of AuthClaim from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return AuthClaim.parse_obj(obj)

        _obj = AuthClaim.parse_obj({
            "name": obj.get("name"),
            "user_attribute_mappings": obj.get("user_attribute_mappings"),
            "user_attribute_macros": obj.get("user_attribute_macros")
        })
        return _obj




# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import onelogin
from onelogin.models.oidc_app import OidcApp  # noqa: E501
from onelogin.rest import ApiException

class TestOidcApp(unittest.TestCase):
    """OidcApp unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test OidcApp
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OidcApp`
        """
        model = onelogin.models.oidc_app.OidcApp()  # noqa: E501
        if include_optional :
            return OidcApp(
                id = 775664, 
                name = 'A Sample App', 
                visible = True, 
                description = '', 
                notes = 'This app is in beta.', 
                icon_url = '/images/missing_connector_icon/square/old_original.png', 
                auth_method = 8, 
                policy_id = 56, 
                allow_assumed_signin = False, 
                tab_id = 196885, 
                connector_id = 108419, 
                created_at = '2018-04-12T21:50:42Z', 
                updated_at = '2019-05-16T19:20:34Z', 
                role_ids = [192513], 
                provisioning = onelogin.models.generic_app_provisioning.generic_app_provisioning(
                    enabled = True, ), 
                parameters = { }, 
                enforcement_point = onelogin.models.enforcement_point.enforcement_point(
                    require_sitewide_authentication = False, 
                    conditions = '', 
                    session_expiry_fixed = {"value":30,"unit":1}, 
                    session_expiry_inactivity = {"value":30,"unit":1}, 
                    permissions = 'allow', 
                    token = 'b491c647f5e0cff854ad606722ac98342b4b0882', 
                    target = '', 
                    resources = [{"resource_id":809,"conditions":"","is_path_regex":false,"permissions":"allow","require_auth":false,"path":"/"}], 
                    context_root = '/', 
                    use_target_host_header = False, 
                    vhost = '', 
                    landing_page = '', 
                    case_sensitive = False, ), 
                configuration = onelogin.models.configuration_oidc.configuration_oidc(
                    login_url = '', 
                    redirect_uri = 'https://localhost:3000/callback', 
                    access_token_expiration_minutes = 1, 
                    refresh_token_expiration_minutes = 1, 
                    token_endpoint_auth_method = 0, 
                    oidc_application_type = 0, ), 
                sso = onelogin.models.sso_oidc.sso_oidc(
                    client_id = '78d1d040-20c9-0136-5146-067351775fae92920', )
            )
        else :
            return OidcApp(
                name = 'A Sample App',
                visible = True,
                description = '',
                policy_id = 56,
                connector_id = 108419,
                configuration = onelogin.models.configuration_oidc.configuration_oidc(
                    login_url = '', 
                    redirect_uri = 'https://localhost:3000/callback', 
                    access_token_expiration_minutes = 1, 
                    refresh_token_expiration_minutes = 1, 
                    token_endpoint_auth_method = 0, 
                    oidc_application_type = 0, ),
        )
        """

    def testOidcApp(self):
        """Test OidcApp"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr

class AltErr(BaseModel):
    """
    AltErr
    """
    status_code: Optional[StrictInt] = Field(None, alias="statusCode", description="HTTP error code https://developer.mozilla.org/en-US/docs/Web/HTTP/Status")
    name: Optional[StrictStr] = Field(None, description="Error Code Name")
    message: Optional[StrictStr] = Field(None, description="Description of Error")
    __properties = ["statusCode", "name", "message"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AltErr:
        """Create an instance of AltErr from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AltErr:
        """Create an instance of AltErr from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return AltErr.parse_obj(obj)

        _obj = AltErr.parse_obj({
            "status_code": obj.get("statusCode"),
            "name": obj.get("name"),
            "message": obj.get("message")
        })
        return _obj




# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import onelogin
from onelogin.models.sso_oidc import SsoOidc  # noqa: E501
from onelogin.rest import ApiException

class TestSsoOidc(unittest.TestCase):
    """SsoOidc unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SsoOidc
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SsoOidc`
        """
        model = onelogin.models.sso_oidc.SsoOidc()  # noqa: E501
        if include_optional :
            return SsoOidc(
                client_id = '78d1d040-20c9-0136-5146-067351775fae92920'
            )
        else :
            return SsoOidc(
        )
        """

    def testSsoOidc(self):
        """Test SsoOidc"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import onelogin
from onelogin.models.error import Error  # noqa: E501
from onelogin.rest import ApiException

class TestError(unittest.TestCase):
    """Error unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Error
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Error`
        """
        model = onelogin.models.error.Error()  # noqa: E501
        if include_optional :
            return Error(
                error = False, 
                code = 200, 
                type = 'Success', 
                message = 'Success'
            )
        else :
            return Error(
                code = 200,
                message = 'Success',
        )
        """

    def testError(self):
        """Test Error"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr

class GetAuthFactors200Response(BaseModel):
    """
    GetAuthFactors200Response
    """
    factor_id: Optional[StrictInt] = Field(None, description="Identifier for the factor which will be used for user enrollment")
    name: Optional[StrictStr] = Field(None, description="Authentication factor name, as it appears to administrators in OneLogin.")
    auth_factor_name: Optional[StrictStr] = Field(None, description="Internal use only")
    __properties = ["factor_id", "name", "auth_factor_name"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> GetAuthFactors200Response:
        """Create an instance of GetAuthFactors200Response from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> GetAuthFactors200Response:
        """Create an instance of GetAuthFactors200Response from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return GetAuthFactors200Response.parse_obj(obj)

        _obj = GetAuthFactors200Response.parse_obj({
            "factor_id": obj.get("factor_id"),
            "name": obj.get("name"),
            "auth_factor_name": obj.get("auth_factor_name")
        })
        return _obj




# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class Verb(str, Enum):
    """
    Verbs are used to distinguish between different types of events. Where possible use one of the following verbs to describe the event. Alternately you can create custom verbs to describe other types of actions within your application.
    """

    """
    allowed enum values
    """
    LOG_MINUS_IN = 'log-in'
    LOG_MINUS_OUT = 'log-out'
    LOG_MINUS_IN_MINUS_DENIED = 'log-in-denied'
    AUTHENTICATION_MINUS_CHALLENGE = 'authentication-challenge'
    AUTHENTICATION_MINUS_CHALLENGE_MINUS_PASS = 'authentication-challenge-pass'
    AUTHENTICATION_MINUS_CHALLENGE_MINUS_FAIL = 'authentication-challenge-fail'

    @classmethod
    def from_json(cls, json_str: str) -> Verb:
        """Create an instance of Verb from a JSON string"""
        return Verb(json.loads(json_str))





# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import onelogin
from onelogin.models.client_app_full import ClientAppFull  # noqa: E501
from onelogin.rest import ApiException

class TestClientAppFull(unittest.TestCase):
    """ClientAppFull unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ClientAppFull
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ClientAppFull`
        """
        model = onelogin.models.client_app_full.ClientAppFull()  # noqa: E501
        if include_optional :
            return ClientAppFull(
                scopes = [
                    onelogin.models.scope.scope(
                        id = 25, 
                        value = 'read:contacts', 
                        description = 'Read some contacts', )
                    ], 
                app_id = 1026152, 
                name = 'An oidc app', 
                api_auth_id = 1033034
            )
        else :
            return ClientAppFull(
        )
        """

    def testClientAppFull(self):
        """Test ClientAppFull"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import onelogin
from onelogin.models.get_role_by_id200_response_data_inner import GetRoleById200ResponseDataInner  # noqa: E501
from onelogin.rest import ApiException

class TestGetRoleById200ResponseDataInner(unittest.TestCase):
    """GetRoleById200ResponseDataInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test GetRoleById200ResponseDataInner
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetRoleById200ResponseDataInner`
        """
        model = onelogin.models.get_role_by_id200_response_data_inner.GetRoleById200ResponseDataInner()  # noqa: E501
        if include_optional :
            return GetRoleById200ResponseDataInner(
                id = 123456, 
                name = 'Employee'
            )
        else :
            return GetRoleById200ResponseDataInner(
        )
        """

    def testGetRoleById200ResponseDataInner(self):
        """Test GetRoleById200ResponseDataInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictInt
from onelogin.models.get_risk_scores200_response_scores import GetRiskScores200ResponseScores

class GetRiskScores200Response(BaseModel):
    """
    GetRiskScores200Response
    """
    scores: Optional[GetRiskScores200ResponseScores] = None
    total: Optional[StrictInt] = None
    __properties = ["scores", "total"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> GetRiskScores200Response:
        """Create an instance of GetRiskScores200Response from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of scores
        if self.scores:
            _dict['scores'] = self.scores.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> GetRiskScores200Response:
        """Create an instance of GetRiskScores200Response from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return GetRiskScores200Response.parse_obj(obj)

        _obj = GetRiskScores200Response.parse_obj({
            "scores": GetRiskScores200ResponseScores.from_dict(obj.get("scores")) if obj.get("scores") is not None else None,
            "total": obj.get("total")
        })
        return _obj

